<?php

namespace Drupal\diboo_core;

use Drupal\diboo_core\Entity\Chain;
use Drupal\diboo_core\Entity\ChainLink;
use Drupal\diboo_core\Entity\Room;

/**
 * Workaround for Drupal bundle classes.
 *
 * Drupal bundle classes can not be shared by multiple bundles.
 * In diboo_core_entity_bundle_info_alter() the bundle machine
 * name is appended to the bundle class name to make it unique,
 * those classes do not exist so when the are being autoloaded
 * this function is invoked to make the class "exists" as
 * a child class of the main one.
 */
class AutoloadBundleClasses {

  /**
   * Define new bundle classes.
   *
   * @param string $unfoundClassName
   *   Class to autoload.
   */
  public static function autoload($unfoundClassName): void {
    foreach ([Room::class, Chain::class, ChainLink::class] as $className) {
      // Prefix matches.
      if (!str_starts_with($unfoundClassName, $className . '_')) {
        continue;
      }
      $bundleSuffix = str_replace($className, '', $unfoundClassName);
      // Safety check for the eval.
      if (!preg_match('/^[a-z_0-9]+$/', $bundleSuffix)) {
        return;
      }
      $namespace = 'Drupal\\diboo_core\\Entity';
      $classBaseName = str_replace($namespace . '\\', '', $className);
      // phpcs:ignore
      eval('namespace ' . $namespace . '; class ' . $classBaseName . $bundleSuffix . ' extends \\' . $className . ' {}');
      return;
    }
  }

}
