<?php

namespace Drupal\diboo_core\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\extra_field\Plugin\ExtraFieldDisplayBase;

/**
 * Extra field plugin OpenChains.
 *
 * The bundles will be changed later in
 * diboo_core_extra_field_display_info_alter()
 * to display only on nodes that are rooms.
 *
 * @ExtraFieldDisplay(
 *   id = "diboo_core_finished_chains",
 *   label = @Translation("Finished Chains"),
 *   bundles = {
 *     "node.*",
 *   }
 * )
 */
final class FinishedChains extends ExtraFieldDisplayBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getLabel() : TranslatableMarkup {
    return $this->t('Finished chains');
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelDisplay(): string {
    return 'above';
  }

  /**
   * {@inheritdoc}
   */
  public function view(ContentEntityInterface $room) : array {
    $render = [
      'title' => [
        '#type' => 'html_tag',
        '#tag' => 'h5',
        '#value' => $this->t('Finished chains'),
      ],
      'finished_chains' => [
        '#type' => 'view',
        '#name' => 'diboo_finished_chains',
        '#display_id' => 'embed',
        '#arguments' => [$room->id()],
        '#embed' => TRUE,
      ],
    ];

    return $render;
  }

}
