<?php

namespace Drupal\diboo_core\Plugin\ExtraField\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\extra_field\Plugin\ExtraFieldFormBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Example Extra field form display.
 *
 * @ExtraFieldForm(
 *   id = "diboo_core_last_chain_link",
 *   label = @Translation("Last chain link"),
 *   description = @Translation("When a new chain link the last one is displayed to base the description on it."),
 *   bundles = {
 *     "node.*"
 *   },
 *   visible = false
 * )
 */
final class LastChainLink extends ExtraFieldFormBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs a OpenChains object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\Routing\RouteMatchInterface $routeMatch
   *   The route match service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EntityTypeManagerInterface $entityTypeManager,
    protected RouteMatchInterface $routeMatch,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('current_route_match'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(array &$form, FormStateInterface $form_state): array {
    $chain = $this->routeMatch->getParameter('chain');
    if (!$chain) {
      return ['#markup' => ''];
    }
    $chainLinks = $chain->get('diboo_chain_links')->referencedEntities();
    $lastChainLink = end($chainLinks);

    // Only phrases will display the title field.
    if ($lastChainLink->get('type')->first()->get('entity')->getValue()->getThirdPartySetting('diboo_core', 'chain_link_type')) {
      $lastChainLink->set('title', '');
    }

    $viewBuilder = $this->entityTypeManager->getViewBuilder('node');
    $render = $viewBuilder->view($lastChainLink, 'diboo_chain_link');
    $render['#theme'] = 'node__diboo_chain_link';
    return $render;
  }

}
